@@ -17,11 +17,11 @@ limitations under the License.
 from langtrace_python_sdk import langtrace
 from langtrace_python_sdk.utils.with_root_span import with_langtrace_root_span
 from langtrace_python_sdk.utils.prompt_registry import get_prompt_from_registry
-from langtrace_python_sdk.utils.with_root_span import send_user_feedback
+from langtrace_python_sdk.utils.with_root_span import SendUserFeedback
 
 __all__ = [
     "langtrace",
     "with_langtrace_root_span",
     "get_prompt_from_registry",
-    "send_user_feedback",
+    "SendUserFeedback",
 ]
